==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/CStmtSwitch__24Case.h <==
// class org.dellroad.jc.cgen.CStmtSwitch$Case

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c08a9e62d60f5455 org_dellroad_jc_cgen_CStmtSwitch__24Case

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_CStmtSwitch__24Case_H_
#define _JC_org_dellroad_jc_cgen_CStmtSwitch__24Case_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Unit$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$sub_refs	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$sub_nonrefs	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$refs	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$refs;
typedef struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$nonrefs	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$object	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$object;

typedef const struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vmethods	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vtable	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vtype	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$method$_init$49a7b9f40ae98036(_jc_env *, struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$object *, jint, struct _jc_object *);

// Virtual methods
extern jint _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$method$compareTo$84fc6fc4a23c98a3(_jc_env *, struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$method_info$compareTo$84fc6fc4a23c98a3;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vmethods {
	jint	(*compareTo$84fc6fc4a23c98a3)(_jc_env *, struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vmethods	org_dellroad_jc_cgen_CStmtSwitch__24Case;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$sub_refs {
	struct _jc_object	*target;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$refs {
    _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$sub_refs	org_dellroad_jc_cgen_CStmtSwitch__24Case;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$sub_nonrefs	org_dellroad_jc_cgen_CStmtSwitch__24Case;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$object {
	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vtype _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_CStmtSwitch__24Case, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_CStmtSwitch__24Case_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/CStmtSwitch__24Case.h <==
// class org.dellroad.jc.cgen.CStmtSwitch$Case

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c08a9e62d60f5455 org_dellroad_jc_cgen_CStmtSwitch__24Case

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_CStmtSwitch__24Case_H_
#define _JC_org_dellroad_jc_cgen_CStmtSwitch__24Case_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Unit$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$sub_refs	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$sub_nonrefs	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$refs	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$refs;
typedef struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$nonrefs	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$object	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$object;

typedef const struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vmethods	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vtable	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vtype	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$method$_init$49a7b9f40ae98036(_jc_env *, struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$object *, jint, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$method$compareTo$84fc6fc4a23c98a3(_jc_env *, struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$method_info$compareTo$84fc6fc4a23c98a3;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vmethods {
	jint	(*compareTo$84fc6fc4a23c98a3)(_jc_env *, struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vmethods	org_dellroad_jc_cgen_CStmtSwitch__24Case;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$sub_refs {
	struct _jc_object	*target;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$refs {
    _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$sub_refs	org_dellroad_jc_cgen_CStmtSwitch__24Case;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$sub_nonrefs	org_dellroad_jc_cgen_CStmtSwitch__24Case;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$object {
	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$vtype _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_CStmtSwitch__24Case, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_CStmtSwitch__24Case$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_CStmtSwitch__24Case_H_ */
